@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,6 +27,28 @@ module VersionsHelper
     end
   end
 
+  def version_filtered_issues_path(version, options = {})
+    options = {:fixed_version_id => version, :set_filter => 1}.merge(options)
+    project = case version.sharing
+      when 'hierarchy', 'tree'
+        if version.project && version.project.root.visible?
+          version.project.root
+        else
+          version.project
+        end
+      when 'system'
+        nil
+      else
+        version.project
+    end
+
+    if project
+      project_issues_path(project, options)
+    else
+      issues_path(options)
+    end
+  end
+
   STATUS_BY_CRITERIAS = %w(tracker status priority author assigned_to category)
 
   def render_issue_status_by(version, criteria)
