@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@ class Attachment < ActiveRecord::Base
   cattr_accessor :thumbnails_storage_path
   @@thumbnails_storage_path = File.join(Rails.root, "tmp", "thumbnails")
 
-  before_save :files_to_final_location
+  before_create :files_to_final_location
   after_destroy :delete_from_disk
 
   # Returns an unsaved copy of the attachment
@@ -79,9 +79,6 @@ class Attachment < ActiveRecord::Base
         if @temp_file.respond_to?(:content_type)
           self.content_type = @temp_file.content_type.to_s.chomp
         end
-        if content_type.blank? && filename.present?
-          self.content_type = Redmine::MimeType.of(filename)
-        end
         self.filesize = @temp_file.size
       end
     end
@@ -123,6 +120,10 @@ class Attachment < ActiveRecord::Base
       self.digest = md5.hexdigest
     end
     @temp_file = nil
+
+    if content_type.blank? && filename.present?
+      self.content_type = Redmine::MimeType.of(filename)
+    end
     # Don't save the content type if it's longer than the authorized length
     if self.content_type && self.content_type.length > 255
       self.content_type = nil
