@@ -15,5 +15,5 @@ RedmineApp::Application.configure do
   # Don't care if the mailer can't send
   config.action_mailer.raise_delivery_errors = false
 
-  config.active_support.deprecation = :log
+  config.active_support.deprecation = [:stderr, :log]
 end
