@@ -20,3 +20,9 @@ Redmine::Plugin.load
 unless Redmine::Configuration['mirror_plugins_assets_on_startup'] == false
   Redmine::Plugin.mirror_assets
 end
+
+Rails.application.config.to_prepare do
+  Redmine::FieldFormat::RecordList.subclasses.each do |klass|
+    klass.instance.reset_target_class
+  end
+end
\ No newline at end of file
