@@ -5,6 +5,7 @@ ActiveRecord::Schema.define(:version => 0) do
     t.column :parent_id, :integer
     t.column :lft, :integer
     t.column :rgt, :integer
+    t.column :depth, :integer
     t.column :organization_id, :integer
   end
 
@@ -17,6 +18,7 @@ ActiveRecord::Schema.define(:version => 0) do
     t.column :parent_id, :integer
     t.column :lft, :integer
     t.column :rgt, :integer
+    t.column :depth, :integer
     t.column :notable_id, :integer
     t.column :notable_type, :string
   end
@@ -26,6 +28,7 @@ ActiveRecord::Schema.define(:version => 0) do
     t.column :mother_id, :integer
     t.column :red, :integer
     t.column :black, :integer
+    t.column :pitch, :integer
   end
 
   create_table :things, :force => true do |t|
@@ -33,13 +36,39 @@ ActiveRecord::Schema.define(:version => 0) do
     t.column :parent_id, :integer
     t.column :lft, :integer
     t.column :rgt, :integer
+    t.column :depth, :integer
     t.column :children_count, :integer
   end
-  
+
   create_table :brokens, :force => true do |t|
     t.column :name, :string
     t.column :parent_id, :integer
     t.column :lft, :integer
     t.column :rgt, :integer
+    t.column :depth, :integer
+  end
+
+  create_table :orders, :force => true do |t|
+    t.column :name, :string
+    t.column :parent_id, :integer
+    t.column :lft, :integer
+    t.column :rgt, :integer
+    t.column :depth, :integer
+  end
+
+  create_table :positions, :force => true do |t|
+    t.column :name, :string
+    t.column :parent_id, :integer
+    t.column :lft, :integer
+    t.column :rgt, :integer
+    t.column :depth, :integer
+    t.column :position, :integer
+  end
+
+  create_table :no_depths, :force => true do |t|
+    t.column :name, :string
+    t.column :parent_id, :integer
+    t.column :lft, :integer
+    t.column :rgt, :integer
   end
 end
