@@ -341,7 +341,7 @@ module Redmine
         # convert a date/time into the CVS-format
         def time_to_cvstime(time)
           return nil if time.nil?
-          time = Time.now if time == 'HEAD'
+          time = Time.now if (time.kind_of?(String) && time == 'HEAD')
 
           unless time.kind_of? Time
             time = Time.parse(time)
