@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -57,7 +57,7 @@ class BoardsControllerTest < ActionController::TestCase
 
   def test_show_should_display_sticky_messages_first
     Message.update_all(:sticky => 0)
-    Message.update_all({:sticky => 1}, {:id => 1})
+    Message.where({:id => 1}).update_all({:sticky => 1})
 
     get :show, :project_id => 1, :id => 1
     assert_response :success
@@ -139,7 +139,7 @@ class BoardsControllerTest < ActionController::TestCase
       post :create, :project_id => 1, :board => { :name => 'Testing', :description => 'Testing board creation'}
     end
     assert_redirected_to '/projects/ecookbook/settings/boards'
-    board = Board.first(:order => 'id DESC')
+    board = Board.order('id DESC').first
     assert_equal 'Testing', board.name
     assert_equal 'Testing board creation', board.description
   end
@@ -150,7 +150,7 @@ class BoardsControllerTest < ActionController::TestCase
       post :create, :project_id => 1, :board => { :name => 'Testing', :description => 'Testing', :parent_id => 2}
     end
     assert_redirected_to '/projects/ecookbook/settings/boards'
-    board = Board.first(:order => 'id DESC')
+    board = Board.order('id DESC').first
     assert_equal Board.find(2), board.parent
   end
 
