@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -32,6 +32,7 @@ class SessionStartTest < ActionController::TestCase
 end
 
 class SessionsTest < ActionController::TestCase
+  include Redmine::I18n
   tests WelcomeController
 
   fixtures :users
@@ -108,6 +109,20 @@ class SessionsTest < ActionController::TestCase
     end
   end
 
+  def test_expired_user_session_should_set_locale
+    set_language_if_valid 'it'
+    user = User.find(2)
+    user.language = 'fr'
+    user.save!
+
+    with_settings :session_timeout => '60' do
+      get :index, {}, {:user_id => user.id, :atime => 4.hours.ago.utc.to_i}
+      assert_redirected_to '/login'
+      assert_include "Veuillez vous reconnecter", flash[:error]
+      assert_equal :fr, current_language
+    end
+  end
+
   def test_anonymous_session_should_not_be_reset
     with_settings :session_lifetime => '720', :session_timeout => '60' do
       get :index
