@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,6 +37,8 @@ class Redmine::ApiTest::CustomFieldsTest < Redmine::ApiTest::Base
         assert_select 'possible_values[type=array]' do
           assert_select 'possible_value>value', :text => 'PostgreSQL'
         end
+        assert_select 'trackers[type=array]'
+        assert_select 'roles[type=array]'
       end
     end
   end
