@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -162,6 +162,20 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
     end
   end
 
+  test "GET /issues/:id.xml with journals should format timestamps in ISO 8601" do
+    get '/issues/1.xml?include=journals'
+
+    iso_date = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}Z$/
+    assert_select 'issue>created_on', :text => iso_date
+    assert_select 'issue>updated_on', :text => iso_date
+    assert_select 'issue journal>created_on', :text => iso_date
+  end
+
+  def test_index_should_include_issue_attributes
+    get '/issues.xml'
+    assert_select 'issues>issue>is_private', :text => 'false'
+  end
+
   def test_index_should_allow_timestamp_filtering
     Issue.delete_all
     Issue.generate!(:subject => '1').update_column(:updated_on, Time.parse("2014-01-02T10:25:00Z"))
@@ -476,6 +490,11 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
     end
   end
 
+  def test_show_should_include_issue_attributes
+    get '/issues/1.xml'
+    assert_select 'issue>is_private', :text => 'false'
+  end
+
   test "GET /issues/:id.xml?include=watchers should include watchers" do
     Watcher.create!(:user_id => 3, :watchable => Issue.find(1))
 
