@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -302,26 +302,35 @@ RAW
   end
 
   def test_macro_thumbnail
-    link = link_to('<img alt="testfile.PNG" src="http://test.host/attachments/thumbnail/17" />'.html_safe,
-                   "http://test.host/attachments/17",
+    link = link_to('<img alt="testfile.PNG" src="/attachments/thumbnail/17" />'.html_safe,
+                   "/attachments/17",
                    :class => "thumbnail",
                    :title => "testfile.PNG")
     assert_equal "<p>#{link}</p>",
                  textilizable("{{thumbnail(testfile.png)}}", :object => Issue.find(14))
   end
 
-  def test_macro_thumbnail_with_size
-    link = link_to('<img alt="testfile.PNG" src="http://test.host/attachments/thumbnail/17/200" />'.html_safe,
+  def test_macro_thumbnail_with_full_path
+    link = link_to('<img alt="testfile.PNG" src="http://test.host/attachments/thumbnail/17" />'.html_safe,
                    "http://test.host/attachments/17",
                    :class => "thumbnail",
                    :title => "testfile.PNG")
+    assert_equal "<p>#{link}</p>",
+                 textilizable("{{thumbnail(testfile.png)}}", :object => Issue.find(14), :only_path => false)
+  end
+
+  def test_macro_thumbnail_with_size
+    link = link_to('<img alt="testfile.PNG" src="/attachments/thumbnail/17/200" />'.html_safe,
+                   "/attachments/17",
+                   :class => "thumbnail",
+                   :title => "testfile.PNG")
     assert_equal "<p>#{link}</p>",
                  textilizable("{{thumbnail(testfile.png, size=200)}}", :object => Issue.find(14))
   end
 
   def test_macro_thumbnail_with_title
-    link = link_to('<img alt="testfile.PNG" src="http://test.host/attachments/thumbnail/17" />'.html_safe,
-                   "http://test.host/attachments/17",
+    link = link_to('<img alt="testfile.PNG" src="/attachments/thumbnail/17" />'.html_safe,
+                   "/attachments/17",
                    :class => "thumbnail",
                    :title => "Cool image")
     assert_equal "<p>#{link}</p>",
