@@ -1,7 +1,7 @@
 # encoding: utf-8
 #
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -67,6 +67,7 @@ class MailHandlerTest < ActiveSupport::TestCase
     # Email notification should be sent
     mail = ActionMailer::Base.deliveries.last
     assert_not_nil mail
+    assert mail.subject.include?("##{issue.id}")
     assert mail.subject.include?('New ticket on a given project')
   end
 
@@ -539,6 +540,28 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal str, issue.subject
   end
 
+  def test_quoted_printable_utf8
+    issue = submit_email(
+              'quoted_printable_utf8.eml',
+              :issue => {:project => 'ecookbook'}
+            )
+    assert_kind_of Issue, issue
+    str = "Freundliche Gr\xc3\xbcsse"
+    str.force_encoding('UTF-8') if str.respond_to?(:force_encoding)
+    assert_equal str, issue.description
+  end
+
+  def test_gmail_iso8859_2
+    issue = submit_email(
+              'gmail-iso8859-2.eml',
+              :issue => {:project => 'ecookbook'}
+            )
+    assert_kind_of Issue, issue
+    str = "Na \xc5\xa1triku se su\xc5\xa1i \xc5\xa1osi\xc4\x87."
+    str.force_encoding('UTF-8') if str.respond_to?(:force_encoding)
+    assert issue.description.include?(str)
+  end
+
   def test_add_issue_with_japanese_subject
     issue = submit_email(
               'subject_japanese_1.eml',
@@ -625,6 +648,19 @@ class MailHandlerTest < ActiveSupport::TestCase
     end
   end
 
+  test "should not ignore Auto-Submitted headers not defined in RFC3834" do
+    [
+      "Auto-Submitted: auto-forwarded"
+    ].each do |header|
+      raw = IO.read(File.join(FIXTURES_PATH, 'ticket_on_given_project.eml'))
+      raw = header + "\n" + raw
+
+      assert_difference 'Issue.count', 1 do
+        assert_not_nil MailHandler.receive(raw), "email with #{header} header was ignored"
+      end
+    end
+  end
+
   def test_add_issue_should_send_email_notification
     Setting.notified_events = ['issue_added']
     ActionMailer::Base.deliveries.clear
@@ -644,6 +680,30 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal 'Feature request', journal.issue.tracker.name
   end
 
+  def test_update_issue_should_accept_issue_id_after_space_inside_brackets
+    journal = submit_email('ticket_reply_with_status.eml') do |email|
+      assert email.sub!(/^Subject:.*$/, "Subject: Re: [Feature request #2] Add ingredients categories")
+    end
+    assert journal.is_a?(Journal)
+    assert_equal Issue.find(2), journal.journalized
+  end
+
+  def test_update_issue_should_accept_issue_id_inside_brackets
+    journal = submit_email('ticket_reply_with_status.eml') do |email|
+      assert email.sub!(/^Subject:.*$/, "Subject: Re: [#2] Add ingredients categories")
+    end
+    assert journal.is_a?(Journal)
+    assert_equal Issue.find(2), journal.journalized
+  end
+
+  def test_update_issue_should_ignore_bogus_issue_ids_in_subject
+    journal = submit_email('ticket_reply_with_status.eml') do |email|
+      assert email.sub!(/^Subject:.*$/, "Subject: Re: [12345#1][bogus#1][Feature request #2] Add ingredients categories")
+    end
+    assert journal.is_a?(Journal)
+    assert_equal Issue.find(2), journal.journalized
+  end
+
   def test_update_issue_with_attribute_changes
     # This email contains: 'Status: Resolved'
     journal = submit_email('ticket_reply_with_status.eml')
@@ -820,6 +880,20 @@ class MailHandlerTest < ActiveSupport::TestCase
     assert_equal issue.subject, 'New ticket on a given project with a very long subject line which exceeds 255 chars and should not be ignored but chopped off. And if the subject line is still not long enough, we just add more text. And more text. Wow, this is really annoying. Especially, if you have nothing to say...'[0,255]
   end
 
+  def test_first_keyword_should_be_matched
+    issue = submit_email('ticket_with_duplicate_keyword.eml', :allow_override => 'priority')
+    assert issue.is_a?(Issue)
+    assert_equal 'High', issue.priority.name
+  end
+
+  def test_keyword_after_delimiter_should_be_ignored
+    with_settings :mail_handler_body_delimiters => "== DELIMITER ==" do
+      issue = submit_email('ticket_with_keyword_after_delimiter.eml', :allow_override => 'priority')
+      assert issue.is_a?(Issue)
+      assert_equal 'Normal', issue.priority.name
+    end
+  end
+
   def test_new_user_from_attributes_should_return_valid_user
     to_test = {
       # [address, name] => [login, firstname, lastname]
