@@ -1,5 +1,5 @@
 # Redmine - project management software
-# Copyright (C) 2006-2014  Jean-Philippe Lang
+# Copyright (C) 2006-2015  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -76,6 +76,36 @@ class RepositoryTest < ActiveSupport::TestCase
     assert_equal repository, project.repository
   end
 
+  def test_2_repositories_with_same_identifier_in_different_projects_should_be_valid
+    Repository::Subversion.create!(:project_id => 2, :identifier => 'foo', :url => 'file:///foo')
+    r = Repository::Subversion.new(:project_id => 3, :identifier => 'foo', :url => 'file:///bar')
+    assert r.save
+  end
+
+  def test_2_repositories_with_same_identifier_should_not_be_valid
+    Repository::Subversion.create!(:project_id => 3, :identifier => 'foo', :url => 'file:///foo')
+    r = Repository::Subversion.new(:project_id => 3, :identifier => 'foo', :url => 'file:///bar')
+    assert !r.save
+  end
+
+  def test_2_repositories_with_blank_identifier_should_not_be_valid
+    Repository::Subversion.create!(:project_id => 3, :identifier => '', :url => 'file:///foo')
+    r = Repository::Subversion.new(:project_id => 3, :identifier => '', :url => 'file:///bar')
+    assert !r.save
+  end
+
+  def test_2_repositories_with_blank_identifier_and_one_as_default_should_not_be_valid
+    Repository::Subversion.create!(:project_id => 3, :identifier => '', :url => 'file:///foo', :is_default => true)
+    r = Repository::Subversion.new(:project_id => 3, :identifier => '', :url => 'file:///bar')
+    assert !r.save
+  end
+
+  def test_2_repositories_with_blank_and_nil_identifier_should_not_be_valid
+    Repository::Subversion.create!(:project_id => 3, :identifier => nil, :url => 'file:///foo')
+    r = Repository::Subversion.new(:project_id => 3, :identifier => '', :url => 'file:///bar')
+    assert !r.save
+  end
+
   def test_first_repository_should_be_set_as_default
     repository1 = Repository::Subversion.new(
                       :project => Project.find(3),
@@ -395,4 +425,69 @@ class RepositoryTest < ActiveSupport::TestCase
       [r1, r2].sort
     end
   end
+
+  def test_stats_by_author_reflect_changesets_and_changes
+    repository = Repository.find(10)
+
+    expected = {"Dave Lopper"=>{:commits_count=>10, :changes_count=>3}}
+    assert_equal expected, repository.stats_by_author
+
+    set = Changeset.create!(
+      :repository => repository,
+      :committer => 'dlopper',
+      :committed_on => Time.now,
+      :revision => 101,
+      :comments => 'Another commit by foo.'
+    )
+    Change.create!(:changeset => set, :action => 'A', :path => '/path/to/file1')
+    Change.create!(:changeset => set, :action => 'A', :path => '/path/to/file2')
+    expected = {"Dave Lopper"=>{:commits_count=>11, :changes_count=>5}}
+    assert_equal expected, repository.stats_by_author
+  end
+
+  def test_stats_by_author_honnor_committers
+    # in fact it is really tested above, but let's have a dedicated test
+    # to ensure things are dynamically linked to Users
+    User.find_by_login("dlopper").update_attribute(:firstname, "Dave's")
+    repository = Repository.find(10)
+    expected = {"Dave's Lopper"=>{:commits_count=>10, :changes_count=>3}}
+    assert_equal expected, repository.stats_by_author
+  end
+
+  def test_stats_by_author_doesnt_drop_unmapped_users
+    repository = Repository.find(10)
+    Changeset.create!(
+      :repository => repository,
+      :committer => 'unnamed <foo@bar.net>',
+      :committed_on => Time.now,
+      :revision => 101,
+      :comments => 'Another commit by foo.'
+    )
+
+    assert repository.stats_by_author.has_key?("unnamed <foo@bar.net>")
+  end
+
+  def test_stats_by_author_merge_correctly
+    # as we honnor users->committer map and it's not injective,
+    # we must be sure merges happen correctly and stats are not
+    # wiped out when two source counts map to the same user.
+    #
+    # Here we have Changeset's with committer="dlopper" and others
+    # with committer="dlopper <dlopper@somefoo.net>"
+    repository = Repository.find(10)
+
+    expected = {"Dave Lopper"=>{:commits_count=>10, :changes_count=>3}}
+    assert_equal expected, repository.stats_by_author
+
+    set = Changeset.create!(
+      :repository => repository,
+      :committer => 'dlopper <dlopper@somefoo.net>',
+      :committed_on => Time.now,
+      :revision => 101,
+      :comments => 'Another commit by foo.'
+    )
+
+    expected = {"Dave Lopper"=>{:commits_count=>11, :changes_count=>3}}
+    assert_equal expected, repository.stats_by_author
+  end
 end
